@@ -28,7 +28,8 @@ def get_command(mod):
 _kinds = [('repo', 'Repository commands'),
           ('stack', 'Stack (branch) commands'),
           ('patch', 'Patch commands'),
-          ('wc', 'Index/worktree commands')]
+          ('wc', 'Index/worktree commands'),
+          ('alias', 'Alias commands')]
 _kind_order = [kind for kind, desc in _kinds]
 _kinds = dict(_kinds)
 
@@ -68,7 +69,10 @@ def _command_list(commands):
         kinds.setdefault(kind, {})[cmd] = help
     for kind in _kind_order:
         kind = _kinds[kind]
-        yield kind, sorted(kinds[kind].iteritems())
+        try:
+            yield kind, sorted(kinds[kind].iteritems())
+        except KeyError:
+            pass
 
 def pretty_command_list(commands, f):
     cmd_len = max(len(cmd) for cmd in commands.iterkeys())
