@@ -109,7 +109,7 @@ def color_diff_flags():
 def check_local_changes():
     if git.local_changes():
         raise CmdException('local changes in the tree. Use "refresh" or'
-                           ' "status --reset"')
+                           ' "reset --hard"')
 
 def check_head_top_equal(crt_series):
     if not crt_series.head_top_equal():
@@ -121,7 +121,7 @@ def check_conflicts():
     if git.get_conflicts():
         raise CmdException('Unsolved conflicts. Please fix the conflicts'
                            ' then use "git add --update <files>" or revert the'
-                           ' changes with "status --reset".')
+                           ' changes with "reset --hard".')
 
 def print_crt_patch(crt_series, branch = None):
     if not branch:
@@ -192,6 +192,16 @@ def pop_patches(crt_series, patches, keep = False):
         crt_series.pop_patch(p, keep)
         out.done()
 
+def get_patch_from_list(part_name, patch_list):
+    candidates = [full for full in patch_list if str.find(full, part_name) != -1]
+    if len(candidates) >= 2:
+        out.info('Possible patches:\n  %s' % '\n  '.join(candidates))
+        raise CmdException, 'Ambiguous patch name "%s"' % part_name
+    elif len(candidates) == 1:
+        return candidates[0]
+    else:
+        return None
+
 def parse_patches(patch_args, patch_list, boundary = 0, ordered = False):
     """Parse patch_args list for patch names in patch_list and return
     a list. The names can be individual patches and/or in the
@@ -470,7 +480,7 @@ def update_commit_data(cd, options):
     """Return a new CommitData object updated according to the command line
     options."""
     # Set the commit message from commandline.
-    if options.message != None:
+    if options.message is not None:
         cd = cd.set_message(options.message)
 
     # Modify author data.
@@ -488,7 +498,7 @@ def update_commit_data(cd, options):
 
     # Let user edit the commit message manually, unless
     # --save-template or --message was specified.
-    if not getattr(options, 'save_template', None) and not options.message:
+    if not getattr(options, 'save_template', None) and options.message is None:
         cd = cd.set_message(edit_string(cd.message, '.stgit-new.txt'))
 
     return cd
