@@ -25,7 +25,7 @@ from stgit import argparse
 
 help = 'Push patches to the top, even if applied'
 kind = 'stack'
-usage = ['<patches>',
+usage = ['[--] <patches>',
          '-s <series>']
 description = """
 Push a patch or a range of patches to the top even if applied. The
@@ -75,7 +75,7 @@ def func(parser, options, args):
 
     iw = stack.repository.default_iw
     clean_iw = (not options.keep and iw) or None
-    trans = transaction.StackTransaction(stack, 'sink',
+    trans = transaction.StackTransaction(stack, 'float',
                                          check_clean_iw = clean_iw)
 
     try:
