@@ -24,7 +24,7 @@ from stgit import argparse, stack, git
 
 help = 'Integrate a GNU diff patch into the current patch'
 kind = 'patch'
-usage = ['[options] [<file>]']
+usage = ['[options] [--] [<file>]']
 description = """
 Apply the given GNU diff file (or the standard input) onto the top of
 the current patch. With the '--threeway' option, the patch is applied
