@@ -22,7 +22,7 @@ from stgit.argparse import opt
 
 help = 'Push or pop patches to the given one'
 kind = 'stack'
-usage = ['<patch-name>']
+usage = ['[options] [--] <patch-name>']
 description = """
 Push/pop patches to/from the stack until the one given on the command
 line becomes current."""
@@ -42,6 +42,13 @@ def func(parser, options, args):
     clean_iw = (not options.keep and iw) or None
     trans = transaction.StackTransaction(stack, 'goto',
                                          check_clean_iw = clean_iw)
+
+    if not patch in trans.all_patches:
+        candidate = common.get_patch_from_list(patch, trans.all_patches)
+        if candidate is None:
+            raise common.CmdException('Patch "%s" does not exist' % patch)
+        patch = candidate
+
     if patch in trans.applied:
         to_pop = set(trans.applied[trans.applied.index(patch)+1:])
         assert not trans.pop_patches(lambda pn: pn in to_pop)
@@ -57,8 +64,6 @@ def func(parser, options, args):
                                  already_merged = pn in merged)
         except transaction.TransactionHalted:
             pass
-    elif patch in trans.hidden:
-        raise common.CmdException('Cannot goto a hidden patch')
     else:
-        raise common.CmdException('Patch "%s" does not exist' % patch)
+        raise common.CmdException('Cannot goto a hidden patch')
     return trans.run(iw)
