@@ -22,7 +22,7 @@ from stgit.argparse import opt
 
 help = 'Hide a patch in the series'
 kind = 'stack'
-usage = ['[options] <patch-range>']
+usage = ['[options] [--] <patch-range>']
 description = """
 Hide a range of unapplied patches so that they are no longer shown in
 the plain 'series' command output."""
