@@ -23,7 +23,7 @@ from stgit.argparse import opt
 
 help = 'Push one or more patches onto the stack'
 kind = 'stack'
-usage = ['[options] [<patch1>] [<patch2>] [<patch3>..<patch4>]']
+usage = ['[options] [--] [<patch1>] [<patch2>] [<patch3>..<patch4>]']
 description = """
 Push one or more patches (defaulting to the first unapplied one) onto
 the stack. The 'push' operation allows patch reordering by commuting
@@ -41,7 +41,10 @@ options = [
     opt('-a', '--all', action = 'store_true',
         short = 'Push all the unapplied patches'),
     opt('-n', '--number', type = 'int',
-        short = 'Push the specified number of patches'),
+        short = 'Push the specified number of patches', long = '''
+        Push the specified number of patches.
+
+        With a negative number, push all but that many patches.'''),
     opt('--reverse', action = 'store_true',
         short = 'Push the patches in reverse order'),
     opt('--set-tree', action = 'store_true',
@@ -64,15 +67,19 @@ def func(parser, options, args):
     stack = directory.repository.current_stack
     iw = stack.repository.default_iw
     clean_iw = (not options.keep and iw) or None
-    trans = transaction.StackTransaction(stack, 'pop',
+    trans = transaction.StackTransaction(stack, 'push',
                                          check_clean_iw = clean_iw)
 
+    if options.number == 0:
+        # explicitly allow this without any warning/error message
+        return
+
     if not trans.unapplied:
         raise common.CmdException('No patches to push')
 
     if options.all:
         patches = list(trans.unapplied)
-    elif options.number:
+    elif options.number is not None:
         patches = trans.unapplied[:options.number]
     elif not args:
         patches = [trans.unapplied[0]]
