@@ -26,12 +26,16 @@ from stgit import argparse, utils
 
 help = 'Generate a new commit for the current patch'
 kind = 'patch'
-usage = ['[options] [<files or dirs>]']
+usage = ['[options] [--] [<files or dirs>]']
 description = """
 Include the latest work tree and index changes in the current patch.
 This command generates a new git commit object for the patch; the old
 commit is no longer visible.
 
+Refresh will warn if the index is dirty, and require use of either the '--index'
+or '--force' options to override this check. This is to prevent accidental full
+refresh when only some changes were staged using git add interative mode.
+
 You may optionally list one or more files or directories relative to
 the current working directory; if you do, only matching files will be
 updated.
@@ -56,6 +60,10 @@ options = [
         short = 'Refresh from index instead of worktree', long = """
         Instead of setting the patch top to the current contents of
         the worktree, set it to the current contents of the index."""),
+    opt('-F', '--force', action = 'store_true',
+        short = 'Force refresh even if index is dirty', long = """
+        Instead of warning the user when some work has already been staged (such
+        as with git add interactive mode) force a full refresh."""),
     opt('-p', '--patch', args = [argparse.other_applied_patches,
                                  argparse.unapplied_patches],
         short = 'Refresh (applied) PATCH instead of the top patch'),
@@ -231,6 +239,10 @@ def func(parser, options, args):
         raise common.CmdException(
             'Only full refresh is available with the --index option')
 
+    if options.index and options.force:
+        raise common.CmdException(
+            'You cannot --force a full refresh when using --index mode')
+
     stack = directory.repository.current_stack
     patch_name = get_patch(stack, options.patch)
     paths = list_files(stack, patch_name, args, options.index, options.update)
@@ -241,6 +253,13 @@ def func(parser, options, args):
         raise common.CmdException(
             'Cannot refresh -- resolve conflicts first')
 
+    # Make sure the index is clean before performing a full refresh
+    if not options.index and not options.force:
+        if not (stack.repository.default_index.is_clean(stack.head) or
+                stack.repository.default_iw.worktree_clean()):
+            raise common.CmdException(
+                'The index is dirty. Did you mean --index? To force a full refresh use --force.')
+
     # Commit index to temp patch, and absorb it into the target patch.
     retval, temp_name = make_temp_patch(
         stack, patch_name, paths, temp_index = path_limiting)
