@@ -23,7 +23,7 @@ from stgit import argparse
 
 help = 'Send patches deeper down the stack'
 kind = 'stack'
-usage = ['[-t <target patch>] [-n] [<patches>]']
+usage = ['[-t <target patch>] [-n] [--] [<patches>]']
 description = """
 This is the opposite operation of linkstg:float[]: move the specified
 patches down the stack.  It is for example useful to group stable
@@ -33,7 +33,7 @@ easily committed or pushed.
 
 If no patch is specified on command-line, the current patch gets sunk.
 By default patches are sunk to the bottom of the stack, but the '--to'
-option allows to place them under any applied patch.
+option allows one to place them under any applied patch.
 
 Sinking internally involves popping all patches (or all patches
 including <target patch>), then pushing the patches to sink, and then
@@ -89,7 +89,8 @@ def func(parser, options, args):
                                          check_clean_iw = clean_iw)
 
     try:
-        trans.reorder_patches(applied, unapplied, iw = iw)
+        trans.reorder_patches(applied, unapplied, iw = iw,
+                              allow_interactive = True)
     except transaction.TransactionHalted:
         pass
     return trans.run(iw)
