@@ -25,7 +25,7 @@ from stgit import argparse, stack, git
 
 help = 'Synchronise patches with a branch or a series'
 kind = 'patch'
-usage = ['[options] [<patch1>] [<patch2>] [<patch3>..<patch4>]']
+usage = ['[options] [--] [<patch1>] [<patch2>] [<patch3>..<patch4>]']
 description = """
 For each of the specified patches perform a three-way merge with the
 same patch in the specified branch or series. The command can be used
