@@ -25,8 +25,8 @@ from stgit import argparse, utils
 
 help = 'Turn regular git commits into StGit patches'
 kind = 'stack'
-usage = ['<patch-name-1> [<patch-name-2> ...]',
-         '-n NUM [<prefix>]',
+usage = ['[--] <patch-name-1> [<patch-name-2> ...]',
+         '-n NUM [--] [<prefix>]',
          '-t <committish> [-x]']
 description = """
 Take one or more git commits at the base of the current stack and turn
@@ -71,6 +71,11 @@ def func(parser, options, args):
             parser.error('cannot specify patch name with --to')
         patch_nr = patchnames = None
         to_commit = stack.repository.rev_parse(options.to)
+        # check whether the --to commit is on a different branch
+        merge_bases = directory.repository.get_merge_bases(to_commit, stack.base)
+        if not to_commit in merge_bases:
+            to_commit = merge_bases[0]
+            options.exclusive = True
     elif options.number:
         if options.number <= 0:
             parser.error('invalid value passed to --number')
@@ -90,23 +95,24 @@ def func(parser, options, args):
         patchnames = args
         patch_nr = len(patchnames)
 
-    def get_parent(c):
-        next = c.data.parents
+    def check_and_append(c, n):
+        next = n.data.parents;
         try:
             [next] = next
         except ValueError:
+            out.done()
             raise common.CmdException(
                 'Trying to uncommit %s, which does not have exactly one parent'
-                % c.sha1)
-        return next
+                % n.sha1)
+        return c.append(n)
 
     commits = []
     next_commit = stack.base
     if patch_nr:
         out.start('Uncommitting %d patches' % patch_nr)
         for i in xrange(patch_nr):
-            commits.append(next_commit)
-            next_commit = get_parent(next_commit)
+            check_and_append(commits, next_commit)
+            next_commit = next_commit.data.parent
     else:
         if options.exclusive:
             out.start('Uncommitting to %s (exclusive)' % to_commit.sha1)
@@ -115,10 +121,10 @@ def func(parser, options, args):
         while True:
             if next_commit == to_commit:
                 if not options.exclusive:
-                    commits.append(next_commit)
+                    check_and_append(commits, next_commit)
                 break
-            commits.append(next_commit)
-            next_commit = get_parent(next_commit)
+            check_and_append(commits, next_commit)
+            next_commit = next_commit.data.parent
         patch_nr = len(commits)
 
     taken_names = set(stack.patchorder.all)
