@@ -34,7 +34,7 @@ def _print_current_patch(old_applied, new_applied):
         now_at(new_applied[-1])
 
 class _TransPatchMap(dict):
-    """Maps patch names to sha1 strings."""
+    """Maps patch names to Commit objects."""
     def __init__(self, stack):
         dict.__init__(self)
         self.__stack = stack
@@ -90,7 +90,6 @@ class StackTransaction(object):
         self.__applied = list(self.__stack.patchorder.applied)
         self.__unapplied = list(self.__stack.patchorder.unapplied)
         self.__hidden = list(self.__stack.patchorder.hidden)
-        self.__conflicting_push = None
         self.__error = None
         self.__current_tree = self.__stack.head.data.tree
         self.__base = self.__stack.base
@@ -153,9 +152,9 @@ class StackTransaction(object):
             self.__abort()
     def __assert_index_worktree_clean(self, iw):
         if not iw.worktree_clean():
-            self.__halt('Worktree not clean. Use "refresh" or "status --reset"')
+            self.__halt('Worktree not clean. Use "refresh" or "reset --hard"')
         if not iw.index.is_clean(self.stack.head):
-            self.__halt('Index not clean. Use "refresh" or "status --reset"')
+            self.__halt('Index not clean. Use "refresh" or "reset --hard"')
     def __checkout(self, tree, iw, allow_bad_head):
         if not allow_bad_head:
             self.__assert_head_top_equal()
@@ -232,10 +231,9 @@ class StackTransaction(object):
             self.__stack.patchorder.hidden = self.__hidden
             log.log_entry(self.__stack, msg)
         old_applied = self.__stack.patchorder.applied
-        write(self.__msg)
-        if self.__conflicting_push != None:
-            self.__patches = _TransPatchMap(self.__stack)
-            self.__conflicting_push()
+        if not self.__conflicts:
+            write(self.__msg)
+        else:
             write(self.__msg + ' (CONFLICT)')
         if print_current_patch:
             _print_current_patch(old_applied, self.__applied)
@@ -358,26 +356,24 @@ class StackTransaction(object):
         elif not merge_conflict and cd.is_nochange():
             s = 'empty'
         out.done(s)
-        def update():
-            if comm:
-                self.patches[pn] = comm
-            if pn in self.hidden:
-                x = self.hidden
-            else:
-                x = self.unapplied
-            del x[x.index(pn)]
-            self.applied.append(pn)
+
         if merge_conflict:
             # We've just caused conflicts, so we must allow them in
             # the final checkout.
             self.__allow_conflicts = lambda trans: True
 
-            # Save this update so that we can run it a little later.
-            self.__conflicting_push = update
-            self.__halt("%d merge conflict(s)" % len(self.__conflicts))
+        # Update the stack state
+        if comm:
+            self.patches[pn] = comm
+        if pn in self.hidden:
+            x = self.hidden
         else:
-            # Update immediately.
-            update()
+            x = self.unapplied
+        del x[x.index(pn)]
+        self.applied.append(pn)
+
+        if merge_conflict:
+            self.__halt("%d merge conflict(s)" % len(self.__conflicts))
 
     def push_tree(self, pn):
         """Push the named patch without updating its tree."""
@@ -401,7 +397,8 @@ class StackTransaction(object):
         del x[x.index(pn)]
         self.applied.append(pn)
 
-    def reorder_patches(self, applied, unapplied, hidden = None, iw = None):
+    def reorder_patches(self, applied, unapplied, hidden = None, iw = None,
+                        allow_interactive = False):
         """Push and pop patches to attain the given ordering."""
         if hidden is None:
             hidden = self.hidden
@@ -410,17 +407,23 @@ class StackTransaction(object):
         to_pop = set(self.applied[common:])
         self.pop_patches(lambda pn: pn in to_pop)
         for pn in applied[common:]:
-            self.push_patch(pn, iw)
+            self.push_patch(pn, iw, allow_interactive = allow_interactive)
+
+        # We only get here if all the pushes succeeded.
         assert self.applied == applied
         assert set(self.unapplied + self.hidden) == set(unapplied + hidden)
         self.unapplied = unapplied
         self.hidden = hidden
 
-    def check_merged(self, patches):
+    def check_merged(self, patches, tree = None, quiet = False):
         """Return a subset of patches already merged."""
-        out.start('Checking for patches merged upstream')
+        if not quiet:
+            out.start('Checking for patches merged upstream')
         merged = []
-        if self.temp_index_tree != self.stack.head.data.tree:
+        if tree:
+            self.temp_index.read_tree(tree)
+            self.temp_index_tree = tree
+        elif self.temp_index_tree != self.stack.head.data.tree:
             self.temp_index.read_tree(self.stack.head.data.tree)
             self.temp_index_tree = self.stack.head.data.tree
         for pn in reversed(patches):
@@ -437,5 +440,6 @@ class StackTransaction(object):
                 self.temp_index_tree = None
             except git.MergeException:
                 pass
-        out.done('%d found' % len(merged))
+        if not quiet:
+            out.done('%d found' % len(merged))
         return merged
