@@ -438,6 +438,9 @@ class Series(PatchSet):
             return []
         return read_strings(self.__hidden_file)
 
+    def set_hidden(self, hidden):
+        write_strings(self.__hidden_file, hidden)
+
     def get_base(self):
         # Return the parent of the bottommost patch, if there is one.
         if os.path.isfile(self.__applied_file):
@@ -620,7 +623,7 @@ class Series(PatchSet):
         if value:
             config.set('branch.%s.stgit.parentbranch' % target_series, value)
 
-    def delete(self, force = False):
+    def delete(self, force = False, cleanup = False):
         """Deletes an stgit series
         """
         if self.is_initialised():
@@ -628,7 +631,8 @@ class Series(PatchSet):
                     self.get_hidden();
             if not force and patches:
                 raise StackException, \
-                      'Cannot delete: the series still contains patches'
+                      'Cannot %s: the series still contains patches' % \
+                        ('delete', 'clean up')[cleanup]
             for p in patches:
                 self.get_patch(p).delete()
 
@@ -660,12 +664,13 @@ class Series(PatchSet):
                 raise StackException('Series directory %s is not empty'
                                      % self._dir())
 
-        try:
-            git.delete_branch(self.get_name())
-        except git.GitException:
-            out.warn('Could not delete branch "%s"' % self.get_name())
+        if not cleanup:
+            try:
+                git.delete_branch(self.get_name())
+            except git.GitException:
+                out.warn('Could not delete branch "%s"' % self.get_name())
+            config.remove_section('branch.%s' % self.get_name())
 
-        config.remove_section('branch.%s' % self.get_name())
         config.remove_section('branch.%s.stgit' % self.get_name())
 
     def refresh_patch(self, files = None, message = None, edit = False,
