@@ -11,11 +11,11 @@ EOF
 
 test_expect_success 'Setup' '
     echo "Fjäderholmarna" > skärgårdsö.txt &&
-    git add skärgårdsö.txt &&
+    stg add skärgårdsö.txt &&
     git commit -m "Create island" &&
     stg init &&
     echo foo > unrelated.txt &&
-    git add unrelated.txt &&
+    stg add unrelated.txt &&
     stg new p0 -m "Unrelated file" &&
     stg refresh &&
     stg pop &&
@@ -38,7 +38,7 @@ test_expect_success 'Setup' '
 '
 
 cat > expected.txt <<EOF
-M skärgårdsö.txt
+ M "sk\303\244rg\303\245rds\303\266.txt"
 EOF
 test_expect_success 'Status of modified non-ASCII file' '
     stg status > output.txt &&
